@@ -1,9 +1,17 @@
-##' Illustrate the effect of multicollinearity in regression.
+##' Illustrate multicollinearity in regression, part 1.
 ##'
+##' @description
 ##' This is a set of functions that faciliates the examination
 ##' of multicollinearity. Suppose the "true" relationship is
 ##'  y[i] = 0.2 * x1[i] + 0.2 * x2[i] + e
 ##' where e is Normal(0, stde^2).
+##'
+##' mcGraph1 draws the 3D regression space, but all of the points
+##' are illustrated "in" the flat plane of x1-x2 variables.
+##'
+##' @details
+##' These functions are specialized to a particular purpose. If you
+##' just want to draw 3D regressions, look at plotPlane.
 ##' @name mcGraph1
 ##' @param x1 a predictor vector
 ##' @param x2 a predictor vector
@@ -12,10 +20,12 @@
 ##' @param x2lab label for the x2 axis, (the one called "ylab" inside persp)
 ##' @param ylab  label for the y (vertical) axis (the one called "zlab" inside persp)
 ##' @param ... additional parameters passed to persp
-##' @export mcGraph1
-##' @return The perspective matrix from persp (that can be used with trans3d to add more details in the plot)
+##' @export
+##' @rdname mcGraph
+##' @return mcGraph1 and mcGraph2 return only the perspective matrix
+##' from persp. It is returned so that users can add additional embellishments on the 3D plot (can be used with trans3d)
 ##' @keywords regression hplot
-##' @author Paul Johnson <pauljohn@@ku.edu>
+##' @author Paul E. Johnson <pauljohn@@ku.edu>
 ##' @examples
 ##' set.seed(12345)
 ##' ## Create data with x1 and x2 correlated at 0.10
@@ -24,42 +34,39 @@
 ##' mcGraph1(dat$x1, dat$x2, dat$y, theta=20, phi=8, ticktype="detailed", nticks=10)
 ##'
 mcGraph1 <- function (x1, x2, y, x1lab, x2lab, ylab, ...){
-  x1range <- magRange(x1, 1.25)
-  x2range <- magRange(x2, 1.25)
-  yrange <- magRange(y, 1.5)
-
-  if (missing(x1lab)) x1lab <- gsub(".*\\$", "", deparse(substitute(x1)))
-  if (missing(x2lab)) x2lab <- gsub(".*\\$", "", deparse(substitute(x2)))
-  if (missing(ylab)) ylab  <- gsub(".*\\$", "", deparse(substitute(y)))
-
-  res <- perspEmpty(x1 = plotSeq(x1range, 5), x2 = plotSeq(x2range,5), y = yrange, x1lab = x1lab, x2lab = x2lab, ylab = ylab, ...)
-
-  yMinimum <- rep(yrange[1] , length(x1))
-  mypoints1 <- trans3d(x1, x2, yMinimum, pmat = res)
-  points( mypoints1, pch = 16, col = "blue")
-  invisible(res)
+    x1range <- magRange(x1, 1.25)
+    x2range <- magRange(x2, 1.25)
+    yrange <- magRange(y, 1.5)
+    
+    if (missing(x1lab)) x1lab <- gsub(".*\\$", "", deparse(substitute(x1)))
+    if (missing(x2lab)) x2lab <- gsub(".*\\$", "", deparse(substitute(x2)))
+    if (missing(ylab)) ylab  <- gsub(".*\\$", "", deparse(substitute(y)))
+    
+    res <- perspEmpty(x1 = plotSeq(x1range, 5),
+                      x2 = plotSeq(x2range,5),
+                      y = yrange, x1lab = x1lab,
+                      x2lab = x2lab, ylab = ylab, ...)
+    
+    yMinimum <- rep(yrange[1] , length(x1))
+    mypoints1 <- trans3d(x1, x2, yMinimum, pmat = res)
+    points( mypoints1, pch = 16, col = "blue")
+    invisible(res)
 }
+NULL
 
-##' mcGraph2 draws a 3-D representation of a scatterplot with shadows in the x1-x2 plane.
+ 
+##' mcGraph2 draws a 3-D representation of a scatterplot with shadows
+##' in the x1-x2 plane.  The observations are represented by blue
+##' points floating above the x1-x2 plane. If scaley=1, the end result
+##' is a scatterplot "cloud" of the y points above the x1-x2 plane,
+##' and gray shadows of the points are cast down from the cloud onto
+##' the x1-x2 plane itself. This uses persp to make the actual
+##' drawing.
 ##'
-##' The observations are represented by blue points floating above the
-##' x1-x2 plane. If scaley=1, the end result is a scatterplot "cloud"
-##' of the y points above the x1-x2 plane, and gray shadows of the
-##' points are cast down from the cloud onto the x1-x2 plane
-##' itself. This uses persp to make the actual drawing.
-##'
-##' @param x1 a predictor vector
-##' @param x2 a predictor vector
-##' @param y  the dependent variable
-##' @param rescaley a single scalar value or a vector of the same length as y.
-##' @param drawArrows TRUE or FALSE, do you want arrows from the bottom up to observed y?
-##' @param x1lab label for the x1 axis, (the one called "xlab" inside persp)
-##' @param x2lab label for the x2 axis, (the one called "ylab" inside persp)
-##' @param ylab  label for the y (vertical) axis (the one called "zlab" inside persp)
-##' @param ... arguments passed to persp
-##' @return The perspective matrix from persp (that can be used with trans3d to add more details in the plot)
-##' @author Paul E. Johnson <pauljohn@@ku.edu>
-##' @export mcGraph2
+##' @param rescaley a single scalar value or a vector of the same
+##' length as y.
+##' @export
+##' @rdname mcGraph
 ##' @examples
 ##' set.seed(12345)
 ##' ## Create data with x1 and x2 correlated at 0.10
@@ -110,25 +117,19 @@ mcGraph2 <- function(x1, x2, y, rescaley = 1, drawArrows = TRUE, x1lab, x2lab, y
     if (drawArrows) arrows(mypoints1$x , mypoints1$y , mypoints2s$x , mypoints2s$y , col="red" , lty = 2, lwd = 0.3, length = 0.1)
     invisible(res)
 }
+NULL
 
-##' mcGraph3 draws a 3-dimensional scatter and a regression plane
+##' With mcGraph3, the observations are scattered in 3-dimensions, the
+##' fitted values are represented by a mesh, and their shadows in the
+##' x1-x2 plane are also represented.
 ##'
-##' The observations are scattered in 3-dimensions, the fitted
-##' values are represented by a mesh, and their
-##' shadows in the x1-x2 plane are also represented.
-##'
-##' @author Paul E. Johnson <pauljohn@@ku.edu>
-##' @param x1 a predictor vector
-##' @param x2 a predictor vector
-##' @param y the dependent variable
 ##' @param interaction a TRUE or FALSE request for inclusion of the x1-x2 interaction in the regression calculation
 ##' @param drawArrows TRUE or FALSE, do you want arrows from the plane to observed y?
-##' @param x1lab label for the x1 axis, (the one called "xlab" inside persp)
-##' @param x2lab label for the x2 axis, (the one called "ylab" inside persp)
-##' @param ylab  label for the y (vertical) axis (the one called "zlab" inside persp)
-##' @param ... optional arguments passed to persp
-##' @return a list of 2 objects, the fitted regression model and the perspective matrix used with persp to draw the image.
-##' @export mcGraph3
+##' @return mcGraph3 returns a list of 2 objects. 1) the fitted
+##' regression model2) the perspective matrix used with persp to draw
+##' the image.
+##' @export
+##' @rdname mcGraph
 ##' @examples
 ##' set.seed(12345)
 ##' ## Create data with x1 and x2 correlated at 0.10
@@ -205,5 +206,5 @@ mcGraph3 <- function(x1, x2, y, interaction = FALSE, drawArrows = TRUE, x1lab, x
     if (drawArrows) arrows(mypoints4$x , mypoints4$y , mypoints2s$x , mypoints2s$y , col = "red" , lty = 4, lwd = 0.3, length = 0.1)
     invisible(list(lm = m1, res = res))
 }
-
+NULL
 
